use strict;
use warnings;

use Test::More;

if( $ENV{RELEASE_TESTING} ) {
    eval "use Test::Pod::Coverage 1.00"; ## no critic (eval)
    plan skip_all =>
        "Test::Pod::Coverage 1.00 required for testing POD coverage"
            if $@;
    diag 'We get a warning generated by Inline about DATA ' .
         "sections being processed by Inline.\nIt\'s known to be harmless.";
}
else {
    plan skip_all => 'Skip: Test::Pod::Coverage tests skipped unless ' .
                     'environment variable RELEASE_TESTING is set.';
}

all_pod_coverage_ok();

